/*
 * 	log.h - Logging function declarations for libglacier
 *
 * 	This file is part of Glacier.
 *
 * 	Glacier is free software: you can redistribute it and/or modify it under the terms of the
 * 	GNU Lesser General Public License as published by the Free Software Foundation, either
 * 	version 3 of the License, or (at your option) any later version.
 *
 * 	Glacier is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * 	without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * 	PARTICULAR PURPOSE. See the GNU Lesser General Public License for more details.
 *
 * 	You should have received a copy of the GNU Lesser General Public License along with Glacier. If
 * 	not, see <https://www.gnu.org/licenses/>.
 */

#ifndef GLACIERLOG_H_
#define GLACIERLOG_H_

/*
 * infolog
 *
 * DESCRIPTION: Infolog outputs a stylized info message. It follows Glacier's uniform CLI style.
 * PARAMETERS:
 * 		char MSG[] -> The message to output
 * RETURN VALUES:
 * 		None.
 * CAVEATS:
 * 		* Cannot output variables. If you must output variables, use printf instead.
 * 		* A NEWLINE ('\n') character is implied, therefore putting one at the end of
 * 		  a string is not needed.
 * EXAMPLE:
 * 		infolog("This is an info message.");
 */

void infolog(char MSG[]);

/**************************************************************************************************************/

/*
 * warnlog
 *
 * DESCRIPTION: Warnlog outputs a stylized warning message. It follows Glacier's uniform CLI style.
 * PARAMETERS:
 * 		char MSG[] -> The message to output
 * RETURN VALUES:
 * 		None.
 * CAVEATS:
 * 		* Cannot output variables. If you must output variables, use printf instead.
 * 		* A NEWLINE ('\n') character is implied, therefore putting one at the end of
 * 		  a string is not needed.
 * EXAMPLE:
 * 		warnlog("This is a warning message.");
 */

void warnlog(char MSG[]);

/**************************************************************************************************************/

/*
 * errlog
 *
 * DESCRIPTION: Errlog outputs a stylized error message. It follows Glacier's uniform CLI style.
 * PARAMETERS:
 * 		char MSG[] -> The message to output
 * RETURN VALUES:
 * 		None.
 * CAVEATS:
 * 		* Cannot output variables. If you must output variables, use printf instead.
 * 		* A NEWLINE ('\n') character is implied, therefore putting one at the end of
 * 		  a string is not needed.
 * EXAMPLE:
 * 		errlog("This is an error message.");
 */

void errlog(char MSG[]);

/**************************************************************************************************************/

/*
 * successlog
 *
 * DESCRIPTION: Successlog outputs a stylized success message. It follows Glacier's uniform CLI style.
 * PARAMETERS:
 * 		char MSG[] -> The message to output
 * RETURN VALUES:
 * 		None.
 * CAVEATS:
 * 		* Cannot output variables. If you must output variables, use printf instead.
 * 		* A NEWLINE ('\n') character is implied, therefore putting one at the end of
 * 		  a string is not needed.
 * EXAMPLE:
 * 		successlog("This is a success message.");
 */

void successlog(char MSG[]);

#endif
