/*
 * 	config.c - Configuration parsing functions
 *
 * 	This file is part of libglacier.
 *
 * 	Liblacier is free software: you can redistribute it and/or modify it under the terms of the
 * 	GNU General Public License as published by the Free Software Foundation, either
 * 	version 3 of the License, or (at your option) any later version.
 *
 * 	Libglacier is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * 	without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * 	PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * 	You should have received a copy of the GNU General Public License along with Libglacier. If
 * 	not, see <https://www.gnu.org/licenses/>.
 */

/* ALL FUNCTIONS IN THIS FILE DEFINED IN: config.h */

/*
 * init_config
 *
 * DESCRIPTION: Initialize libconfig.
 * PARAMETERS: None.
 *
 */

int
init_config(void)
{
	config_init(&cfg);

	if (! config_read_file(&cfg, runtime_files[0])) {
		fprintf(stderr, "%s:%d - %s\n", config_error_file(&cfg),
			config_error_line(&cfg), config_error_text(&cfg));
		config_destroy(&cfg);
		return(EXIT_FAILURE);
	}

	if (LG_VERBOSE == 1) {
		infolog("Initialized libconfig");
	}

	return 0;
}

/*
 * die_config
 *
 * DESCRIPTION: Kill libconfig.
 * PARAMETERS: None.
 *
 */

int
die_config(void)
{
	config_destroy(&cfg);

	if (LG_VERBOSE == 1) {
		infolog("Destroyed libconfig");
	}

	return(EXIT_SUCCESS);
}

/*
 * load_all_from_config
 *
 * DESCRIPTION: Loads all settings from the Glacier config file.
 * PARAMETERS: None.
 *
 */

int
load_all_from_config(void)
{
	/* this is probably really ugly but it works */
	if (! config_lookup_bool(&cfg, "GLACIER_DO_INT_CHECK", &GLACIER_DO_INT_CHECK)) { return 1; }
	if (! config_lookup_bool(&cfg, "GLACIER_VERBOSE",      &GLACIER_VERBOSE)) { return 1; }
	
	return 0;
}

/*
 * load_all_from_profile
 *
 * DESCRIPTION: Loads all settings from the Glacier system profile.
 * PARAMETERS: None.
 *
 */

int
load_all_from_profile(void)
{
	if (! config_lookup_string(&cfg, "GLACIER_REPO", 	     &GLACIER_REPO)) { return 1; }
	if (! config_lookup_string(&cfg, "GLACIER_ARCH",             &GLACIER_ARCH)) { return 1; }
	if (! config_lookup_string(&cfg, "GLACIER_TARGET", 	     &GLACIER_TARGET)) { return 1; }
	if (! config_lookup_string(&cfg, "GLACIER_SYSTEM_PROFILE",   &GLACIER_SYSTEM_PROFILE)) { return 1; }

	return 0;
}

